pub trait DependencyLike {
// Required methods
fn inherit(&self) -> InheritConfiguration;
fn export(&self) -> &Option<String>;
}Expand description
A Spin component dependency. This abstracts over the metadata associated with the dependency. The abstraction allows both manifest and lockfile types to participate in composition.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".